@@ -2,8 +2,8 @@
 /* { dg-skip-if "" { mips-sgi-irix* } { "-mabi=32" } { "" } } */
 /* { dg-options "-mfix-vr4130 -march=vr4130" } */
 #if _MIPS_ARCH_VR4130 && !__mips16 && __mips64
-long long foo (void) { long long r; asm ("# foo" : "=l" (r)); return r; }
+long long foo (void) { long long r; asm ("# foo" : "=h" (r)); return r; }
 #else
-asm ("#\tdmacc\t");
+asm ("#\tdmacchi\t");
 #endif
-/* { dg-final { scan-assembler "\tdmacc\t" } } */
+/* { dg-final { scan-assembler "\tdmacchi\t" } } */
